

*****include the sas macro est_pairedIC.sas;
%include 'D:\CSAWORK\ZeroInflated\est_pairedIC.sas';

****import external data file in .csv format, and name it to "my_data_pH1" sas data set; 
****data file in WIDE format;
	proc import datafile="D:\CSAWORK\ZeroInflated\datawide_pH1.csv" out=my_data_pH1 dbms=csv replace;
    	getnames=yes;
	run;

****change the lower bound of left-censored observations from -999 in the original data set to .;
****change the upper bound of right-censored observations from 999 in the original data set to .;
****save the changes and store the data into a new sas data set named "my_data_pH2";	
	data my_data_pH2;
	set my_data_pH1;
	if lower0=-999 then lower0=.;
	if upper0=999 then upper0=.;
	if lower1=-999 then lower1=.;
	if upper1=999 then upper1=.;
	run;


****call the macro and implement the parameter estimation with the data set my_data_pH2;
%est_pairedIC(indata=my_data_pH2, subjectID=hhID, group=group, logL_T0=lower0, logU_T0=upper0, logL_T1=lower1, logU_T1=upper1, logb1=3, logD=2, outdata=EstOut, seedboot=765, bootn=200, mcQ=1000000, seedmc=234);


****export the EstOut sas data set to an external data file in .csv format ;
****[such exportation is not necessarility needed, can be revoked by deleteing the comments (i.e."/*" and "*/") as the user sees fit];
/*
proc export data=EstOut
   outfile='D:\CSAWORK\ZeroInflated\EstOut.csv'
   dbms=csv
   replace;
run;
*/

****sas code hereafter is for estimation of the bootstrapped variance, and the estimation of 95% confidence intervals;

********[for theta0, theta1 and RR the estimation was on the log-scale, to base e]; 
      data EstOut;
	   set EstOut;
	   lntheta0=log(theta0);
	   lntheta1=log(theta1);
	   lnRR=log(theta1/theta0);
     run;


********extracting the point etimates for the paramaters, save to EstPar sas data set;
      proc transpose data=EstOut(where=(replicate=0)) out=EstPar;
	   var alpha0 alpha1 alpha2 beta0 beta1 beta2 delta0 delta1 delta2 R11 R12 R22 lntheta0 lntheta1 lnRR RD;
      run;


******estimation of variance for the parameter estimates [for theta0, theta1 and RR the estimation was on the log-scale]; 
     proc sort data=EstOut;
	    where replicate>0;
		by R11;
	 run;

    data EstOut;
     set EstOut;
	 rownumber=_N_;
    run;

	 proc summary data=EstOut;
	 ***the following "where" statement allows user to do variance estimation after removing estimates with insensible variance for the rando effect,if preferred;
	 where rownumber<=180;
	    var alpha0 alpha1 alpha2 beta0 beta1 beta2 delta0 delta1 delta2 R11 R12 R22 lntheta0 lntheta1 lnRR RD;
		output out=SE_BOOT VAR=;
	 run;

	 data SE_BOOT;
	   set SE_BOOT;
       drop _TYPE_  _FREQ_;

	 proc transpose data=SE_BOOT out=SE_BOOT_trans;
	 run;


****merge the two sas data set "EstPar" [with point estimates] and "SE_BOOT_trans" [with bootstrapped variance], save to a new sas data set named "FinalTable";
	 proc sort data=EstPar;
	 by _NAME_;

	 data  EstPar;
	  set EstPar;
	  rename COL1=ESTIMATE;

	 proc sort data=SE_BOOT_trans;
	 by _NAME_;

	 data  SE_BOOT_trans;
	  set SE_BOOT_trans;
	  rename COL1=VAR;

	 data FinalTable;
	   merge EstPar SE_BOOT_trans;
	   by _NAME_;
	   run;

******estimation of 95% CI for the parameter estimates;
data FinalTable;
	  set FinalTable;
	  LowerBound_95CI=ESTIMATE-quantile('NORMAL',.975)*sqrt(VAR);
	  UpperBound_95CI=ESTIMATE+quantile('NORMAL',.975)*sqrt(VAR);
	  if _NAME_="lnRR" or _NAME_="lntheta0" or _NAME_="lntheta1" then do;
            ESTIMATE_EXP=exp(ESTIMATE); 
            LowerBound_95CI_EXP=exp(LowerBound_95CI); 
	        UpperBound_95CI_EXP=exp(UpperBound_95CI); 
      end;
	 run;

***export final estimation result;
	 proc export data=FinalTable
     outfile="D:\CSAWORK\ZeroInflated\FinalTable.csv"
     dbms=csv 
     replace;
    run;
